@@ -17,8 +17,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef EXPORTADDRESSBOOKRESOURCEJOB_H
-#define EXPORTADDRESSBOOKRESOURCEJOB_H
+#ifndef EXPORTRESOURCEARCHIVEJOB_H
+#define EXPORTRESOURCEARCHIVEJOB_H
 
 #include <QObject>
 class KZip;
@@ -45,20 +45,18 @@ Q_SIGNALS:
     void info(const QString &str);
     void terminated();
 
-private Q_SLOTS:
-    void slotTerminated(bool success);
-
 public Q_SLOTS:
     void slotTaskCanceled();
 
 private:
+    void slotTerminated(bool success);
     void finished();
     QString mArchiveName;
     QString mUrl;
     QString mArchivePath;
     QString mIdentifier;
-    KZip *mZip;
-    PimSettingBackupThread *mThread;
+    KZip *mZip = nullptr;
+    PimSettingBackupThread *mThread = nullptr;
 };
 
-#endif // EXPORTADDRESSBOOKRESOURCEJOB_H
+#endif // EXPORTRESOURCEARCHIVEJOB_H
