@@ -32,15 +32,15 @@ public:
 
     void start() override;
 
-private Q_SLOTS:
+private:
     void slotCheckBackupResource();
     void slotCheckBackupConfig();
     void slotNoteJobTerminated();
     void slotWriteNextArchiveResource();
-private:
+
     void backupConfig();
     void backupTheme();
-    int mIndexIdentifier;
+    int mIndexIdentifier = 0;
 };
 
 #endif // EXPORTNOTESJOB_H
